@@ -225,6 +225,8 @@ def step_spread(G, incubation_days, infection_duration, transmission_rate, use_p
                 for contact in G.neighborhood(node)[1:]:
                     if G.vs[contact]["agent_status"] == "S":
                         prob = transmission_rate * G[node, contact] # access to the weight of the edge
+                        if prob > 1:
+                            prob = 1
                         # has the new node been infected?
                         G.vs[contact]["agent_status"] = np.random.choice(["S", "E"], p = (1 - prob, prob))
                         if G.vs[contact]["agent_status"] == "E":
